@@ -22,10 +22,11 @@ class SqlalchemyCsvDebugPanel(DebugPanel):
     """
     Panel that displays a link to SQLACSV download
     """
-    name = 'sqlalchemy-csv'
-    template = 'pyramid_debugtoolbar_api_sqlalchemy:templates/sqlalchemy_csv.dbtmako'
-    title = _('SQLAlchemy Queries CSV')
-    nav_title = _('SQLAlchemy CSV')
+
+    name = "sqlalchemy-csv"
+    template = "pyramid_debugtoolbar_api_sqlalchemy:templates/sqlalchemy_csv.dbtmako"
+    title = _("SQLAlchemy Queries CSV")
+    nav_title = _("SQLAlchemy CSV")
 
     def __init__(self, original_request):
         self.token = original_request.registry.pdtb_token
@@ -50,21 +51,22 @@ class SqlalchemyCsvDebugPanel(DebugPanel):
         sqlalchemy_panel = self._sqlalchemy_panel
         if sqlalchemy_panel and sqlalchemy_panel.queries:
             return len(sqlalchemy_panel.queries)
-        return ''
+        return ""
 
     def render_content(self, request):
         sqlalchemy_panel = get_sqlalchemy_panel(request.toolbar_panels.values())
         if not sqlalchemy_panel:
-            return 'No `sqlalchemy` panel in request.'
+            return "No `sqlalchemy` panel in request."
         if not sqlalchemy_panel.queries:
-            return 'No queries in executed in request.'
+            return "No queries in executed in request."
         # our template might want to reference this for button visibility
         self.data = sqlalchemy_panel.data
         return super(SqlalchemyCsvDebugPanel, self).render_content(request)
 
     def render_vars(self, request):
-        return {'route_url': request.route_url,
-                'static_path': request.static_url(STATIC_PATH),
-                'root_path': request.route_url(ROOT_ROUTE_NAME),
-                'pdtb_id': self.pdtb_id,
-                }
+        return {
+            "route_url": request.route_url,
+            "static_path": request.static_url(STATIC_PATH),
+            "root_path": request.route_url(ROOT_ROUTE_NAME),
+            "pdtb_id": self.pdtb_id,
+        }
